# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BndLib module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_bndlib.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BndLib
else:
    import _BndLib

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BndLib.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BndLib.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BndLib.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BndLib.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BndLib.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BndLib.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BndLib.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BndLib.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BndLib.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BndLib.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BndLib.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BndLib.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BndLib.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BndLib.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BndLib.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BndLib.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BndLib.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BndLib:
_BndLib.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BndLib.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.Bnd
import OCC.Core.TColgp
import OCC.Core.BVH
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.GeomAbs
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.TopAbs
import OCC.Core.math
import OCC.Core.Message
import OCC.Core.OSD

from enum import IntEnum
from OCC.Core.Exception import *



class bndlib(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Add(*args) -> "void":
        r"""
        Bounding box for a surface trimmed or not adds the segment of the line l limited by the two parameter values p1 and p2, to the bounding box b, and then enlarges b by the tolerance value tol. tol is the tolerance value to enlarge the minimun and maximum dimension p1 and p2 may represent infinite values. exceptions standard_failure if p1 and p2 are either two negative infinite real numbers, or two positive infinite real numbers.

        Parameters
        ----------
        L: gp_Lin
        P1: float
        P2: float
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        L: gp_Lin2d
        P1: float
        P2: float
        Tol: float
        B: Bnd_Box2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: gp_Circ
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None
        P2-p1 can be in [0,2*pi].

        Parameters
        ----------
        C: gp_Circ
        P1: float
        P2: float
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: gp_Circ2d
        Tol: float
        B: Bnd_Box2d

        Returns
        -------
        None
        Adds the circle c, or the arc of the circle c limited by the two parameter values p1 and p2, to the bounding box b, and then enlarges b by the tolerance value tol. p2-p1 can be in [0,2*pi].

        Parameters
        ----------
        C: gp_Circ2d
        P1: float
        P2: float
        Tol: float
        B: Bnd_Box2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: gp_Elips
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None
        P2-p1 can be in [0,2*pi].

        Parameters
        ----------
        C: gp_Elips
        P1: float
        P2: float
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: gp_Elips2d
        Tol: float
        B: Bnd_Box2d

        Returns
        -------
        None
        Adds the ellipse e, or the arc of the ellipse e limited by the two parameter values p1 and p2, to the bounding box b, and then enlarges b by the tolerance value tol. p2-p1 can be in [0,2*pi].

        Parameters
        ----------
        C: gp_Elips2d
        P1: float
        P2: float
        Tol: float
        B: Bnd_Box2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        P: gp_Parab
        P1: float
        P2: float
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None
        Adds the arc of the parabola p limited by the two parameter values p1 and p2, to the bounding box b, and then enlarges b by the tolerance value tol. p1 and p2 may represent infinite values. exceptions standard_failure if p1 and p2 are either two negative infinite real numbers, or two positive infinite real numbers.

        Parameters
        ----------
        P: gp_Parab2d
        P1: float
        P2: float
        Tol: float
        B: Bnd_Box2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        H: gp_Hypr
        P1: float
        P2: float
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None
        Adds the arc of the branch of hyperbola h limited by the two parameter values p1 and p2, to the bounding box b, and then enlarges b by the tolerance value tol. p1 and p2 may represent infinite values. exceptions standard_failure if p1 and p2 are either two negative infinite real numbers, or two positive infinite real numbers.

        Parameters
        ----------
        H: gp_Hypr2d
        P1: float
        P2: float
        Tol: float
        B: Bnd_Box2d

        Returns
        -------
        None
        Umax -umin can be in [0,2*pi].

        Parameters
        ----------
        S: gp_Cylinder
        UMin: float
        UMax: float
        VMin: float
        VMax: float
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None
        Adds to the bounding box b, the patch of the cylinder s limited - in the v parametric direction, by the two parameter values vmin and vmax - and optionally in the u parametric direction, by the two parameter values umin and umax. b is then enlarged by the tolerance value tol. vmin and vmax may represent infinite values. exceptions standard_failure if vmin and vmax are either two negative infinite real numbers, or two positive infinite real numbers.

        Parameters
        ----------
        S: gp_Cylinder
        VMin: float
        VMax: float
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None
        Umax-umin can be in [0,2*pi].

        Parameters
        ----------
        S: gp_Cone
        UMin: float
        UMax: float
        VMin: float
        VMax: float
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None
        Adds to the bounding box b, the patch of the cone s limited - in the v parametric direction, by the two parameter values vmin and vmax - and optionally in the u parametric direction, by the two parameter values umin and umax, b is then enlarged by the tolerance value tol. vmin and vmax may represent infinite values. exceptions standard_failure if vmin and vmax are either two negative infinite real numbers, or two positive infinite real numbers.

        Parameters
        ----------
        S: gp_Cone
        VMin: float
        VMax: float
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        S: gp_Sphere
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None
        Adds to the bounding box b the sphere s, or - the patch of the sphere s, limited in the u parametric direction, by the two parameter values umin and umax, and in the v parametric direction, by the two parameter values vmin and vmax. b is then enlarged by the tolerance value tol. umax-umin can be in [0,2*pi] vmin,vmax can be [-pi/2,pi/2].

        Parameters
        ----------
        S: gp_Sphere
        UMin: float
        UMax: float
        VMin: float
        VMax: float
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        P: gp_Torus
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None
        Adds to the bounding box b - the torus s, or - the patch of the torus s, limited in the u parametric direction, by the two parameter values umin and umax, and in the v parametric direction, by the two parameter values vmin and vmax. b is then enlarged by the tolerance value tol. umax-umin can be in [0,2*pi], vmin,vmax can be [-pi/2,pi/2].

        Parameters
        ----------
        P: gp_Torus
        UMin: float
        UMax: float
        VMin: float
        VMax: float
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None

        """
        return _BndLib.bndlib_Add(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _BndLib.bndlib_swiginit(self, _BndLib.new_bndlib())
    __swig_destroy__ = _BndLib.delete_bndlib

# Register bndlib in _BndLib:
_BndLib.bndlib_swigregister(bndlib)

def bndlib_Add(*args) -> "void":
    r"""
    Bounding box for a surface trimmed or not adds the segment of the line l limited by the two parameter values p1 and p2, to the bounding box b, and then enlarges b by the tolerance value tol. tol is the tolerance value to enlarge the minimun and maximum dimension p1 and p2 may represent infinite values. exceptions standard_failure if p1 and p2 are either two negative infinite real numbers, or two positive infinite real numbers.

    Parameters
    ----------
    L: gp_Lin
    P1: float
    P2: float
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    L: gp_Lin2d
    P1: float
    P2: float
    Tol: float
    B: Bnd_Box2d

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    C: gp_Circ
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None
    P2-p1 can be in [0,2*pi].

    Parameters
    ----------
    C: gp_Circ
    P1: float
    P2: float
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    C: gp_Circ2d
    Tol: float
    B: Bnd_Box2d

    Returns
    -------
    None
    Adds the circle c, or the arc of the circle c limited by the two parameter values p1 and p2, to the bounding box b, and then enlarges b by the tolerance value tol. p2-p1 can be in [0,2*pi].

    Parameters
    ----------
    C: gp_Circ2d
    P1: float
    P2: float
    Tol: float
    B: Bnd_Box2d

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    C: gp_Elips
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None
    P2-p1 can be in [0,2*pi].

    Parameters
    ----------
    C: gp_Elips
    P1: float
    P2: float
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    C: gp_Elips2d
    Tol: float
    B: Bnd_Box2d

    Returns
    -------
    None
    Adds the ellipse e, or the arc of the ellipse e limited by the two parameter values p1 and p2, to the bounding box b, and then enlarges b by the tolerance value tol. p2-p1 can be in [0,2*pi].

    Parameters
    ----------
    C: gp_Elips2d
    P1: float
    P2: float
    Tol: float
    B: Bnd_Box2d

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    P: gp_Parab
    P1: float
    P2: float
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None
    Adds the arc of the parabola p limited by the two parameter values p1 and p2, to the bounding box b, and then enlarges b by the tolerance value tol. p1 and p2 may represent infinite values. exceptions standard_failure if p1 and p2 are either two negative infinite real numbers, or two positive infinite real numbers.

    Parameters
    ----------
    P: gp_Parab2d
    P1: float
    P2: float
    Tol: float
    B: Bnd_Box2d

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    H: gp_Hypr
    P1: float
    P2: float
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None
    Adds the arc of the branch of hyperbola h limited by the two parameter values p1 and p2, to the bounding box b, and then enlarges b by the tolerance value tol. p1 and p2 may represent infinite values. exceptions standard_failure if p1 and p2 are either two negative infinite real numbers, or two positive infinite real numbers.

    Parameters
    ----------
    H: gp_Hypr2d
    P1: float
    P2: float
    Tol: float
    B: Bnd_Box2d

    Returns
    -------
    None
    Umax -umin can be in [0,2*pi].

    Parameters
    ----------
    S: gp_Cylinder
    UMin: float
    UMax: float
    VMin: float
    VMax: float
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None
    Adds to the bounding box b, the patch of the cylinder s limited - in the v parametric direction, by the two parameter values vmin and vmax - and optionally in the u parametric direction, by the two parameter values umin and umax. b is then enlarged by the tolerance value tol. vmin and vmax may represent infinite values. exceptions standard_failure if vmin and vmax are either two negative infinite real numbers, or two positive infinite real numbers.

    Parameters
    ----------
    S: gp_Cylinder
    VMin: float
    VMax: float
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None
    Umax-umin can be in [0,2*pi].

    Parameters
    ----------
    S: gp_Cone
    UMin: float
    UMax: float
    VMin: float
    VMax: float
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None
    Adds to the bounding box b, the patch of the cone s limited - in the v parametric direction, by the two parameter values vmin and vmax - and optionally in the u parametric direction, by the two parameter values umin and umax, b is then enlarged by the tolerance value tol. vmin and vmax may represent infinite values. exceptions standard_failure if vmin and vmax are either two negative infinite real numbers, or two positive infinite real numbers.

    Parameters
    ----------
    S: gp_Cone
    VMin: float
    VMax: float
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    S: gp_Sphere
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None
    Adds to the bounding box b the sphere s, or - the patch of the sphere s, limited in the u parametric direction, by the two parameter values umin and umax, and in the v parametric direction, by the two parameter values vmin and vmax. b is then enlarged by the tolerance value tol. umax-umin can be in [0,2*pi] vmin,vmax can be [-pi/2,pi/2].

    Parameters
    ----------
    S: gp_Sphere
    UMin: float
    UMax: float
    VMin: float
    VMax: float
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    P: gp_Torus
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None
    Adds to the bounding box b - the torus s, or - the patch of the torus s, limited in the u parametric direction, by the two parameter values umin and umax, and in the v parametric direction, by the two parameter values vmin and vmax. b is then enlarged by the tolerance value tol. umax-umin can be in [0,2*pi], vmin,vmax can be [-pi/2,pi/2].

    Parameters
    ----------
    P: gp_Torus
    UMin: float
    UMax: float
    VMin: float
    VMax: float
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None

    """
    return _BndLib.bndlib_Add(*args)

class BndLib_Add2dCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Add(*args) -> "void":
        r"""
        Adds to the bounding box b the curve c b is then enlarged by the tolerance value tol. note: depending on the type of curve, one of the following representations of the curve c is used to include it in the bounding box b: - an exact representation if c is built from a line, a circle or a conic curve, - the poles of the curve if c is built from a bezier curve or a bspline curve, - if not, the points of an approximation of the curve c. warning c is an adapted curve, that is, an object which is an interface between: - the services provided by a 2d curve from the package geom2d - and those required of the curve by the computation algorithm. the adapted curve is created in the following way: opencascade::handle<geom2d_curve> mycurve = ... ; geom2dadaptor_curve c(mycurve); the bounding box b is then enlarged by adding it: bnd_box2d b; // ... standard_real tol = ... ; add2dcurve::add ( c, tol, b ); exceptions standard_failure if the curve is built from: - a geom_line, or - a geom_parabola, or - a geom_hyperbola, and p1 and p2 are either two negative infinite real numbers, or two positive infinite real numbers.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Tol: float
        B: Bnd_Box2d

        Returns
        -------
        None
        Adds to the bounding box bthe arc of the curve c limited by the two parameter values p1 and p2. b is then enlarged by the tolerance value tol. note: depending on the type of curve, one of the following representations of the curve c is used to include it in the bounding box b: - an exact representation if c is built from a line, a circle or a conic curve, - the poles of the curve if c is built from a bezier curve or a bspline curve, - if not, the points of an approximation of the curve c. warning c is an adapted curve, that is, an object which is an interface between: - the services provided by a 2d curve from the package geom2d - and those required of the curve by the computation algorithm. the adapted curve is created in the following way: opencascade::handle<geom2d_curve> mycurve = ... ; geom2dadaptor_curve c(mycurve); the bounding box b is then enlarged by adding it: bnd_box2d b; // ... standard_real tol = ... ; add2dcurve::add ( c, tol, b ); exceptions standard_failure if the curve is built from: - a geom_line, or - a geom_parabola, or - a geom_hyperbola, and p1 and p2 are either two negative infinite real numbers, or two positive infinite real numbers.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        U1: float
        U2: float
        Tol: float
        B: Bnd_Box2d

        Returns
        -------
        None
        Adds to the bounding box b the curve c b is then enlarged by the tolerance value tol. note: depending on the type of curve, one of the following representations of the curve c is used to include it in the bounding box b: - an exact representation if c is built from a line, a circle or a conic curve, - the poles of the curve if c is built from a bezier curve or a bspline curve, - if not, the points of an approximation of the curve c.

        Parameters
        ----------
        C: Geom2d_Curve
        Tol: float
        Box: Bnd_Box2d

        Returns
        -------
        None
        Adds to the bounding box b the part of curve c b is then enlarged by the tolerance value tol. u1, u2 - the parametric range to comute the bounding box; note: depending on the type of curve, one of the following representations of the curve c is used to include it in the bounding box b: - an exact representation if c is built from a line, a circle or a conic curve, - the poles of the curve if c is built from a bezier curve or a bspline curve, - if not, the points of an approximation of the curve c.

        Parameters
        ----------
        C: Geom2d_Curve
        U1: float
        U2: float
        Tol: float
        B: Bnd_Box2d

        Returns
        -------
        None

        """
        return _BndLib.BndLib_Add2dCurve_Add(*args)

    @staticmethod
    def AddOptimal(*args) -> "void":
        r"""
        Adds to the bounding box b the part of curve c b is then enlarged by the tolerance value tol. u1, u2 - the parametric range to comute the bounding box; note: depending on the type of curve, one of the following algorithms is used to include it in the bounding box b: - an exact analytical if c is built from a line, a circle or a conic curve, - numerical calculation of bounding box sizes, based on minimization algorithm, for other types of curve if tol = < precision::pconfusion(), precision::pconfusion is used as tolerance for calculation.

        Parameters
        ----------
        C: Geom2d_Curve
        U1: float
        U2: float
        Tol: float
        B: Bnd_Box2d

        Returns
        -------
        None

        """
        return _BndLib.BndLib_Add2dCurve_AddOptimal(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _BndLib.BndLib_Add2dCurve_swiginit(self, _BndLib.new_BndLib_Add2dCurve())
    __swig_destroy__ = _BndLib.delete_BndLib_Add2dCurve

# Register BndLib_Add2dCurve in _BndLib:
_BndLib.BndLib_Add2dCurve_swigregister(BndLib_Add2dCurve)

def BndLib_Add2dCurve_Add(*args) -> "void":
    r"""
    Adds to the bounding box b the curve c b is then enlarged by the tolerance value tol. note: depending on the type of curve, one of the following representations of the curve c is used to include it in the bounding box b: - an exact representation if c is built from a line, a circle or a conic curve, - the poles of the curve if c is built from a bezier curve or a bspline curve, - if not, the points of an approximation of the curve c. warning c is an adapted curve, that is, an object which is an interface between: - the services provided by a 2d curve from the package geom2d - and those required of the curve by the computation algorithm. the adapted curve is created in the following way: opencascade::handle<geom2d_curve> mycurve = ... ; geom2dadaptor_curve c(mycurve); the bounding box b is then enlarged by adding it: bnd_box2d b; // ... standard_real tol = ... ; add2dcurve::add ( c, tol, b ); exceptions standard_failure if the curve is built from: - a geom_line, or - a geom_parabola, or - a geom_hyperbola, and p1 and p2 are either two negative infinite real numbers, or two positive infinite real numbers.

    Parameters
    ----------
    C: Adaptor2d_Curve2d
    Tol: float
    B: Bnd_Box2d

    Returns
    -------
    None
    Adds to the bounding box bthe arc of the curve c limited by the two parameter values p1 and p2. b is then enlarged by the tolerance value tol. note: depending on the type of curve, one of the following representations of the curve c is used to include it in the bounding box b: - an exact representation if c is built from a line, a circle or a conic curve, - the poles of the curve if c is built from a bezier curve or a bspline curve, - if not, the points of an approximation of the curve c. warning c is an adapted curve, that is, an object which is an interface between: - the services provided by a 2d curve from the package geom2d - and those required of the curve by the computation algorithm. the adapted curve is created in the following way: opencascade::handle<geom2d_curve> mycurve = ... ; geom2dadaptor_curve c(mycurve); the bounding box b is then enlarged by adding it: bnd_box2d b; // ... standard_real tol = ... ; add2dcurve::add ( c, tol, b ); exceptions standard_failure if the curve is built from: - a geom_line, or - a geom_parabola, or - a geom_hyperbola, and p1 and p2 are either two negative infinite real numbers, or two positive infinite real numbers.

    Parameters
    ----------
    C: Adaptor2d_Curve2d
    U1: float
    U2: float
    Tol: float
    B: Bnd_Box2d

    Returns
    -------
    None
    Adds to the bounding box b the curve c b is then enlarged by the tolerance value tol. note: depending on the type of curve, one of the following representations of the curve c is used to include it in the bounding box b: - an exact representation if c is built from a line, a circle or a conic curve, - the poles of the curve if c is built from a bezier curve or a bspline curve, - if not, the points of an approximation of the curve c.

    Parameters
    ----------
    C: Geom2d_Curve
    Tol: float
    Box: Bnd_Box2d

    Returns
    -------
    None
    Adds to the bounding box b the part of curve c b is then enlarged by the tolerance value tol. u1, u2 - the parametric range to comute the bounding box; note: depending on the type of curve, one of the following representations of the curve c is used to include it in the bounding box b: - an exact representation if c is built from a line, a circle or a conic curve, - the poles of the curve if c is built from a bezier curve or a bspline curve, - if not, the points of an approximation of the curve c.

    Parameters
    ----------
    C: Geom2d_Curve
    U1: float
    U2: float
    Tol: float
    B: Bnd_Box2d

    Returns
    -------
    None

    """
    return _BndLib.BndLib_Add2dCurve_Add(*args)

def BndLib_Add2dCurve_AddOptimal(*args) -> "void":
    r"""
    Adds to the bounding box b the part of curve c b is then enlarged by the tolerance value tol. u1, u2 - the parametric range to comute the bounding box; note: depending on the type of curve, one of the following algorithms is used to include it in the bounding box b: - an exact analytical if c is built from a line, a circle or a conic curve, - numerical calculation of bounding box sizes, based on minimization algorithm, for other types of curve if tol = < precision::pconfusion(), precision::pconfusion is used as tolerance for calculation.

    Parameters
    ----------
    C: Geom2d_Curve
    U1: float
    U2: float
    Tol: float
    B: Bnd_Box2d

    Returns
    -------
    None

    """
    return _BndLib.BndLib_Add2dCurve_AddOptimal(*args)

class BndLib_Add3dCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Add(*args) -> "void":
        r"""
        Adds to the bounding box b the curve c b is then enlarged by the tolerance value tol. note: depending on the type of curve, one of the following representations of the curve c is used to include it in the bounding box b: - an exact representation if c is built from a line, a circle or a conic curve, - the poles of the curve if c is built from a bezier curve or a bspline curve, if not, the points of an approximation of the curve c. warning c is an adapted curve, that is, an object which is an interface between: - the services provided by a 3d curve from the package geom - and those required of the curve by the computation algorithm. the adapted curve is created in the following way: opencascade::handle<geom_curve> mycurve = ... ; geomadaptor_curve c(mycurve); the bounding box b is then enlarged by adding it: bnd_box b; // ... standard_real tol = ... ; add3dcurve::add ( c, tol, b ); exceptions standard_failure if the curve is built from: - a geom_line, or - a geom_parabola, or - a geom_hyperbola, and p1 and p2 are either two negative infinite real numbers, or two positive infinite real numbers.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None
        Adds to the bounding box b the curve c the arc of the curve c limited by the two parameter values p1 and p2. note: depending on the type of curve, one of the following representations of the curve c is used to include it in the bounding box b: - an exact representation if c is built from a line, a circle or a conic curve, - the poles of the curve if c is built from a bezier curve or a bspline curve, if not, the points of an approximation of the curve c. warning c is an adapted curve, that is, an object which is an interface between: - the services provided by a 3d curve from the package geom - and those required of the curve by the computation algorithm. the adapted curve is created in the following way: opencascade::handle<geom_curve> mycurve = ... ; geomadaptor_curve c(mycurve); the bounding box b is then enlarged by adding it: bnd_box b; // ... standard_real tol = ... ; add3dcurve::add ( c, tol, b ); exceptions standard_failure if the curve is built from: - a geom_line, or - a geom_parabola, or - a geom_hyperbola, and p1 and p2 are either two negative infinite real numbers, or two positive infinite real numbers.

        Parameters
        ----------
        C: Adaptor3d_Curve
        U1: float
        U2: float
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None

        """
        return _BndLib.BndLib_Add3dCurve_Add(*args)

    @staticmethod
    def AddGenCurv(*args) -> "void":
        r"""
        Adds to the bounding box b the curve c using numerical minimization algorithms this method is used in addoptimal for not analytical curves. if tol < precision::confusion(), precision:;confusion is used as computation tolerance.

        Parameters
        ----------
        C: Adaptor3d_Curve
        UMin: float
        UMax: float
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None

        """
        return _BndLib.BndLib_Add3dCurve_AddGenCurv(*args)

    @staticmethod
    def AddOptimal(*args) -> "void":
        r"""
        Adds to the bounding box b the curve c these methods use more precise algorithms for building bnd box then methods add(...).

        Parameters
        ----------
        C: Adaptor3d_Curve
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Adaptor3d_Curve
        U1: float
        U2: float
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None

        """
        return _BndLib.BndLib_Add3dCurve_AddOptimal(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _BndLib.BndLib_Add3dCurve_swiginit(self, _BndLib.new_BndLib_Add3dCurve())
    __swig_destroy__ = _BndLib.delete_BndLib_Add3dCurve

# Register BndLib_Add3dCurve in _BndLib:
_BndLib.BndLib_Add3dCurve_swigregister(BndLib_Add3dCurve)

def BndLib_Add3dCurve_Add(*args) -> "void":
    r"""
    Adds to the bounding box b the curve c b is then enlarged by the tolerance value tol. note: depending on the type of curve, one of the following representations of the curve c is used to include it in the bounding box b: - an exact representation if c is built from a line, a circle or a conic curve, - the poles of the curve if c is built from a bezier curve or a bspline curve, if not, the points of an approximation of the curve c. warning c is an adapted curve, that is, an object which is an interface between: - the services provided by a 3d curve from the package geom - and those required of the curve by the computation algorithm. the adapted curve is created in the following way: opencascade::handle<geom_curve> mycurve = ... ; geomadaptor_curve c(mycurve); the bounding box b is then enlarged by adding it: bnd_box b; // ... standard_real tol = ... ; add3dcurve::add ( c, tol, b ); exceptions standard_failure if the curve is built from: - a geom_line, or - a geom_parabola, or - a geom_hyperbola, and p1 and p2 are either two negative infinite real numbers, or two positive infinite real numbers.

    Parameters
    ----------
    C: Adaptor3d_Curve
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None
    Adds to the bounding box b the curve c the arc of the curve c limited by the two parameter values p1 and p2. note: depending on the type of curve, one of the following representations of the curve c is used to include it in the bounding box b: - an exact representation if c is built from a line, a circle or a conic curve, - the poles of the curve if c is built from a bezier curve or a bspline curve, if not, the points of an approximation of the curve c. warning c is an adapted curve, that is, an object which is an interface between: - the services provided by a 3d curve from the package geom - and those required of the curve by the computation algorithm. the adapted curve is created in the following way: opencascade::handle<geom_curve> mycurve = ... ; geomadaptor_curve c(mycurve); the bounding box b is then enlarged by adding it: bnd_box b; // ... standard_real tol = ... ; add3dcurve::add ( c, tol, b ); exceptions standard_failure if the curve is built from: - a geom_line, or - a geom_parabola, or - a geom_hyperbola, and p1 and p2 are either two negative infinite real numbers, or two positive infinite real numbers.

    Parameters
    ----------
    C: Adaptor3d_Curve
    U1: float
    U2: float
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None

    """
    return _BndLib.BndLib_Add3dCurve_Add(*args)

def BndLib_Add3dCurve_AddGenCurv(*args) -> "void":
    r"""
    Adds to the bounding box b the curve c using numerical minimization algorithms this method is used in addoptimal for not analytical curves. if tol < precision::confusion(), precision:;confusion is used as computation tolerance.

    Parameters
    ----------
    C: Adaptor3d_Curve
    UMin: float
    UMax: float
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None

    """
    return _BndLib.BndLib_Add3dCurve_AddGenCurv(*args)

def BndLib_Add3dCurve_AddOptimal(*args) -> "void":
    r"""
    Adds to the bounding box b the curve c these methods use more precise algorithms for building bnd box then methods add(...).

    Parameters
    ----------
    C: Adaptor3d_Curve
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    C: Adaptor3d_Curve
    U1: float
    U2: float
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None

    """
    return _BndLib.BndLib_Add3dCurve_AddOptimal(*args)

class BndLib_AddSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Add(*args) -> "void":
        r"""
        Adds to the bounding box b the surface s b is then enlarged by the tolerance value tol. note: depending on the type of curve, one of the following representations of the surface s is used to include it in the bounding box b: - an exact representation if s is built from a plane, a cylinder, a cone, a sphere or a torus, - the poles of the surface if s is built from a bezier surface or a bspline surface, - the points of an approximation of the surface s in cases other than offset surfaces; - in the case of an offset surface, the basis surface is first included according to the previous rules; then the bounding box is enlarged by the offset value. warning do not use these functions to add a non-finite surface to the bounding box b. if umin, umax, vmin or vmax is an infinite value b will become wholespace. s is an adapted surface, that is, an object which is an interface between: - the services provided by a surface from the package geom - and those required of the surface by the computation algorithm. the adapted surface is created in the following way: opencascade::handle<geom_surface> mysurface = ... ; geomadaptor_surface s(mysurface); the bounding box b is then enlarged by adding this surface: bnd_box b; // ... standard_real tol = ... ; addsurface::add ( s, tol, b );.

        Parameters
        ----------
        S: Adaptor3d_Surface
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None
        Adds to the bounding box b the surface s the patch of the surface s limited in the u parametric direction by the two parameter values umin, umax, and in the v parametric direction by the two parameter values vmin, vmax. note: depending on the type of curve, one of the following representations of the surface s is used to include it in the bounding box b: - an exact representation if s is built from a plane, a cylinder, a cone, a sphere or a torus, - the poles of the surface if s is built from a bezier surface or a bspline surface, - the points of an approximation of the surface s in cases other than offset surfaces; - in the case of an offset surface, the basis surface is first included according to the previous rules; then the bounding box is enlarged by the offset value. warning do not use these functions to add a non-finite surface to the bounding box b. if umin, umax, vmin or vmax is an infinite value b will become wholespace. s is an adapted surface, that is, an object which is an interface between: - the services provided by a surface from the package geom - and those required of the surface by the computation algorithm. the adapted surface is created in the following way: opencascade::handle<geom_surface> mysurface = ... ; geomadaptor_surface s(mysurface); the bounding box b is then enlarged by adding this surface: bnd_box b; // ... standard_real tol = ... ; addsurface::add ( s, tol, b );.

        Parameters
        ----------
        S: Adaptor3d_Surface
        UMin: float
        UMax: float
        VMin: float
        VMax: float
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None

        """
        return _BndLib.BndLib_AddSurface_Add(*args)

    @staticmethod
    def AddGenSurf(*args) -> "void":
        r"""
        Adds to the bounding box b the surface s using numerical minimization algorithms this method is used in addoptimal for not analytical surfaces and torus. if tol < precision::confusion(), precision::confusion is used as computation tolerance.

        Parameters
        ----------
        S: Adaptor3d_Surface
        UMin: float
        UMax: float
        VMin: float
        VMax: float
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None

        """
        return _BndLib.BndLib_AddSurface_AddGenSurf(*args)

    @staticmethod
    def AddOptimal(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: Adaptor3d_Surface
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        S: Adaptor3d_Surface
        UMin: float
        UMax: float
        VMin: float
        VMax: float
        Tol: float
        B: Bnd_Box

        Returns
        -------
        None

        """
        return _BndLib.BndLib_AddSurface_AddOptimal(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _BndLib.BndLib_AddSurface_swiginit(self, _BndLib.new_BndLib_AddSurface())
    __swig_destroy__ = _BndLib.delete_BndLib_AddSurface

# Register BndLib_AddSurface in _BndLib:
_BndLib.BndLib_AddSurface_swigregister(BndLib_AddSurface)

def BndLib_AddSurface_Add(*args) -> "void":
    r"""
    Adds to the bounding box b the surface s b is then enlarged by the tolerance value tol. note: depending on the type of curve, one of the following representations of the surface s is used to include it in the bounding box b: - an exact representation if s is built from a plane, a cylinder, a cone, a sphere or a torus, - the poles of the surface if s is built from a bezier surface or a bspline surface, - the points of an approximation of the surface s in cases other than offset surfaces; - in the case of an offset surface, the basis surface is first included according to the previous rules; then the bounding box is enlarged by the offset value. warning do not use these functions to add a non-finite surface to the bounding box b. if umin, umax, vmin or vmax is an infinite value b will become wholespace. s is an adapted surface, that is, an object which is an interface between: - the services provided by a surface from the package geom - and those required of the surface by the computation algorithm. the adapted surface is created in the following way: opencascade::handle<geom_surface> mysurface = ... ; geomadaptor_surface s(mysurface); the bounding box b is then enlarged by adding this surface: bnd_box b; // ... standard_real tol = ... ; addsurface::add ( s, tol, b );.

    Parameters
    ----------
    S: Adaptor3d_Surface
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None
    Adds to the bounding box b the surface s the patch of the surface s limited in the u parametric direction by the two parameter values umin, umax, and in the v parametric direction by the two parameter values vmin, vmax. note: depending on the type of curve, one of the following representations of the surface s is used to include it in the bounding box b: - an exact representation if s is built from a plane, a cylinder, a cone, a sphere or a torus, - the poles of the surface if s is built from a bezier surface or a bspline surface, - the points of an approximation of the surface s in cases other than offset surfaces; - in the case of an offset surface, the basis surface is first included according to the previous rules; then the bounding box is enlarged by the offset value. warning do not use these functions to add a non-finite surface to the bounding box b. if umin, umax, vmin or vmax is an infinite value b will become wholespace. s is an adapted surface, that is, an object which is an interface between: - the services provided by a surface from the package geom - and those required of the surface by the computation algorithm. the adapted surface is created in the following way: opencascade::handle<geom_surface> mysurface = ... ; geomadaptor_surface s(mysurface); the bounding box b is then enlarged by adding this surface: bnd_box b; // ... standard_real tol = ... ; addsurface::add ( s, tol, b );.

    Parameters
    ----------
    S: Adaptor3d_Surface
    UMin: float
    UMax: float
    VMin: float
    VMax: float
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None

    """
    return _BndLib.BndLib_AddSurface_Add(*args)

def BndLib_AddSurface_AddGenSurf(*args) -> "void":
    r"""
    Adds to the bounding box b the surface s using numerical minimization algorithms this method is used in addoptimal for not analytical surfaces and torus. if tol < precision::confusion(), precision::confusion is used as computation tolerance.

    Parameters
    ----------
    S: Adaptor3d_Surface
    UMin: float
    UMax: float
    VMin: float
    VMax: float
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None

    """
    return _BndLib.BndLib_AddSurface_AddGenSurf(*args)

def BndLib_AddSurface_AddOptimal(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    S: Adaptor3d_Surface
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    S: Adaptor3d_Surface
    UMin: float
    UMax: float
    VMin: float
    VMax: float
    Tol: float
    B: Bnd_Box

    Returns
    -------
    None

    """
    return _BndLib.BndLib_AddSurface_AddOptimal(*args)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.Extrema import *
from OCC.Core.gp import *
from OCC.Core.Bnd import *
from OCC.Core.BVH import *

#the following typedef cannot be wrapped as is
BRepExtrema_ShapeList = NewType('BRepExtrema_ShapeList', Any)

class BRepExtrema_SeqOfSolution:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> BRepExtrema_SolutionElem: ...
    def Last(self) -> BRepExtrema_SolutionElem: ...
    def Length(self) -> int: ...
    def Append(self, theItem: BRepExtrema_SolutionElem) -> BRepExtrema_SolutionElem: ...
    def Prepend(self, theItem: BRepExtrema_SolutionElem) -> BRepExtrema_SolutionElem: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> BRepExtrema_SolutionElem: ...
    def SetValue(self, theIndex: int, theValue: BRepExtrema_SolutionElem) -> None: ...

class BRepExtrema_SupportType(IntEnum):
	BRepExtrema_IsVertex: int = ...
	BRepExtrema_IsOnEdge: int = ...
	BRepExtrema_IsInFace: int = ...
BRepExtrema_IsVertex = BRepExtrema_SupportType.BRepExtrema_IsVertex
BRepExtrema_IsOnEdge = BRepExtrema_SupportType.BRepExtrema_IsOnEdge
BRepExtrema_IsInFace = BRepExtrema_SupportType.BRepExtrema_IsInFace

class BRepExtrema_DistShapeShape:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Shape1: TopoDS_Shape, Shape2: TopoDS_Shape, F: Optional[Extrema_ExtFlag] = Extrema_ExtFlag_MINMAX, A: Optional[Extrema_ExtAlgo] = Extrema_ExtAlgo_Grad) -> None: ...
	@overload
	def __init__(self, Shape1: TopoDS_Shape, Shape2: TopoDS_Shape, theDeflection: float, F: Optional[Extrema_ExtFlag] = Extrema_ExtFlag_MINMAX, A: Optional[Extrema_ExtAlgo] = Extrema_ExtAlgo_Grad) -> None: ...
	def InnerSolution(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def LoadS1(self, Shape1: TopoDS_Shape) -> None: ...
	def LoadS2(self, Shape1: TopoDS_Shape) -> None: ...
	def NbSolution(self) -> int: ...
	def ParOnEdgeS1(self, N: int) -> float: ...
	def ParOnEdgeS2(self, N: int) -> float: ...
	def ParOnFaceS1(self, N: int) -> Tuple[float, float]: ...
	def ParOnFaceS2(self, N: int) -> Tuple[float, float]: ...
	def Perform(self) -> bool: ...
	def PointOnShape1(self, N: int) -> gp_Pnt: ...
	def PointOnShape2(self, N: int) -> gp_Pnt: ...
	def SetAlgo(self, A: Extrema_ExtAlgo) -> None: ...
	def SetDeflection(self, theDeflection: float) -> None: ...
	def SetFlag(self, F: Extrema_ExtFlag) -> None: ...
	def SupportOnShape1(self, N: int) -> TopoDS_Shape: ...
	def SupportOnShape2(self, N: int) -> TopoDS_Shape: ...
	def SupportTypeShape1(self, N: int) -> BRepExtrema_SupportType: ...
	def SupportTypeShape2(self, N: int) -> BRepExtrema_SupportType: ...
	def Value(self) -> float: ...

class BRepExtrema_DistanceSS:
	@overload
	def __init__(self, S1: TopoDS_Shape, S2: TopoDS_Shape, B1: Bnd_Box, B2: Bnd_Box, DstRef: float, F: Optional[Extrema_ExtFlag] = Extrema_ExtFlag_MINMAX, A: Optional[Extrema_ExtAlgo] = Extrema_ExtAlgo_Grad) -> None: ...
	@overload
	def __init__(self, S1: TopoDS_Shape, S2: TopoDS_Shape, B1: Bnd_Box, B2: Bnd_Box, DstRef: float, aDeflection: float, F: Optional[Extrema_ExtFlag] = Extrema_ExtFlag_MINMAX, A: Optional[Extrema_ExtAlgo] = Extrema_ExtAlgo_Grad) -> None: ...
	def DistValue(self) -> float: ...
	def IsDone(self) -> bool: ...
	def Seq1Value(self) -> BRepExtrema_SeqOfSolution: ...
	def Seq2Value(self) -> BRepExtrema_SeqOfSolution: ...
	def SetAlgo(self, A: Extrema_ExtAlgo) -> None: ...
	def SetFlag(self, F: Extrema_ExtFlag) -> None: ...

class BRepExtrema_ElementFilter:
	pass

class BRepExtrema_ExtCC:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, E1: TopoDS_Edge, E2: TopoDS_Edge) -> None: ...
	def Initialize(self, E2: TopoDS_Edge) -> None: ...
	def IsDone(self) -> bool: ...
	def IsParallel(self) -> bool: ...
	def NbExt(self) -> int: ...
	def ParameterOnE1(self, N: int) -> float: ...
	def ParameterOnE2(self, N: int) -> float: ...
	def Perform(self, E1: TopoDS_Edge) -> None: ...
	def PointOnE1(self, N: int) -> gp_Pnt: ...
	def PointOnE2(self, N: int) -> gp_Pnt: ...
	def SquareDistance(self, N: int) -> float: ...
	def TrimmedSquareDistances(self, P11: gp_Pnt, P12: gp_Pnt, P21: gp_Pnt, P22: gp_Pnt) -> Tuple[float, float, float, float]: ...

class BRepExtrema_ExtCF:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, E: TopoDS_Edge, F: TopoDS_Face) -> None: ...
	def Initialize(self, E: TopoDS_Edge, F: TopoDS_Face) -> None: ...
	def IsDone(self) -> bool: ...
	def IsParallel(self) -> bool: ...
	def NbExt(self) -> int: ...
	def ParameterOnEdge(self, N: int) -> float: ...
	def ParameterOnFace(self, N: int) -> Tuple[float, float]: ...
	def Perform(self, E: TopoDS_Edge, F: TopoDS_Face) -> None: ...
	def PointOnEdge(self, N: int) -> gp_Pnt: ...
	def PointOnFace(self, N: int) -> gp_Pnt: ...
	def SquareDistance(self, N: int) -> float: ...

class BRepExtrema_ExtFF:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, F1: TopoDS_Face, F2: TopoDS_Face) -> None: ...
	def Initialize(self, F2: TopoDS_Face) -> None: ...
	def IsDone(self) -> bool: ...
	def IsParallel(self) -> bool: ...
	def NbExt(self) -> int: ...
	def ParameterOnFace1(self, N: int) -> Tuple[float, float]: ...
	def ParameterOnFace2(self, N: int) -> Tuple[float, float]: ...
	def Perform(self, F1: TopoDS_Face, F2: TopoDS_Face) -> None: ...
	def PointOnFace1(self, N: int) -> gp_Pnt: ...
	def PointOnFace2(self, N: int) -> gp_Pnt: ...
	def SquareDistance(self, N: int) -> float: ...

class BRepExtrema_ExtPC:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, V: TopoDS_Vertex, E: TopoDS_Edge) -> None: ...
	def Initialize(self, E: TopoDS_Edge) -> None: ...
	def IsDone(self) -> bool: ...
	def IsMin(self, N: int) -> bool: ...
	def NbExt(self) -> int: ...
	def Parameter(self, N: int) -> float: ...
	def Perform(self, V: TopoDS_Vertex) -> None: ...
	def Point(self, N: int) -> gp_Pnt: ...
	def SquareDistance(self, N: int) -> float: ...
	def TrimmedSquareDistances(self, pnt1: gp_Pnt, pnt2: gp_Pnt) -> Tuple[float, float]: ...

class BRepExtrema_ExtPF:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, TheVertex: TopoDS_Vertex, TheFace: TopoDS_Face, TheFlag: Optional[Extrema_ExtFlag] = Extrema_ExtFlag_MINMAX, TheAlgo: Optional[Extrema_ExtAlgo] = Extrema_ExtAlgo_Grad) -> None: ...
	def Initialize(self, TheFace: TopoDS_Face, TheFlag: Optional[Extrema_ExtFlag] = Extrema_ExtFlag_MINMAX, TheAlgo: Optional[Extrema_ExtAlgo] = Extrema_ExtAlgo_Grad) -> None: ...
	def IsDone(self) -> bool: ...
	def NbExt(self) -> int: ...
	def Parameter(self, N: int) -> Tuple[float, float]: ...
	def Perform(self, TheVertex: TopoDS_Vertex, TheFace: TopoDS_Face) -> None: ...
	def Point(self, N: int) -> gp_Pnt: ...
	def SetAlgo(self, A: Extrema_ExtAlgo) -> None: ...
	def SetFlag(self, F: Extrema_ExtFlag) -> None: ...
	def SquareDistance(self, N: int) -> float: ...

class BRepExtrema_Poly:
	@staticmethod
	def Distance(S1: TopoDS_Shape, S2: TopoDS_Shape, P1: gp_Pnt, P2: gp_Pnt) -> Tuple[bool, float]: ...

class BRepExtrema_ShapeProximity:
	@overload
	def __init__(self, theTolerance: Optional[float] = 0.0) -> None: ...
	@overload
	def __init__(self, theShape1: TopoDS_Shape, theShape2: TopoDS_Shape, theTolerance: Optional[float] = 0.0) -> None: ...
	def ElementSet1(self) -> BRepExtrema_TriangleSet: ...
	def ElementSet2(self) -> BRepExtrema_TriangleSet: ...
	def GetSubShape1(self, theID: int) -> TopoDS_Face: ...
	def GetSubShape2(self, theID: int) -> TopoDS_Face: ...
	def IsDone(self) -> bool: ...
	def LoadShape1(self, theShape1: TopoDS_Shape) -> bool: ...
	def LoadShape2(self, theShape2: TopoDS_Shape) -> bool: ...
	def OverlapSubShapes1(self) -> BRepExtrema_MapOfIntegerPackedMapOfInteger: ...
	def OverlapSubShapes2(self) -> BRepExtrema_MapOfIntegerPackedMapOfInteger: ...
	def Perform(self) -> None: ...
	def SetTolerance(self, theTolerance: float) -> None: ...
	def Tolerance(self) -> float: ...

class BRepExtrema_SolutionElem:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theDist: float, thePoint: gp_Pnt, theSolType: BRepExtrema_SupportType, theVertex: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, theDist: float, thePoint: gp_Pnt, theSolType: BRepExtrema_SupportType, theEdge: TopoDS_Edge, theParam: float) -> None: ...
	@overload
	def __init__(self, theDist: float, thePoint: gp_Pnt, theSolType: BRepExtrema_SupportType, theFace: TopoDS_Face, theU: float, theV: float) -> None: ...
	def Dist(self) -> float: ...
	def Edge(self) -> TopoDS_Edge: ...
	def EdgeParameter(self) -> float: ...
	def Face(self) -> TopoDS_Face: ...
	def FaceParameter(self) -> Tuple[float, float]: ...
	def Point(self) -> gp_Pnt: ...
	def SupportKind(self) -> BRepExtrema_SupportType: ...
	def Vertex(self) -> TopoDS_Vertex: ...

class BRepExtrema_TriangleSet(BVH_PrimitiveSet3d):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theFaces: BRepExtrema_ShapeList) -> None: ...
	def Box(self, theIndex: int) -> False: ...
	def Center(self, theIndex: int, theAxis: int) -> float: ...
	def Clear(self) -> None: ...
	def GetFaceID(self, theIndex: int) -> int: ...
	def GetVertices(self, theIndex: int, theVertex1: BVH_Vec3d, theVertex2: BVH_Vec3d, theVertex3: BVH_Vec3d) -> None: ...
	def Init(self, theFaces: BRepExtrema_ShapeList) -> bool: ...
	def Size(self) -> int: ...
	def Swap(self, theIndex1: int, theIndex2: int) -> None: ...

class BRepExtrema_SelfIntersection(BRepExtrema_ElementFilter):
	@overload
	def __init__(self, theTolerance: Optional[float] = 0.0) -> None: ...
	@overload
	def __init__(self, theShape: TopoDS_Shape, theTolerance: Optional[float] = 0.0) -> None: ...
	def ElementSet(self) -> BRepExtrema_TriangleSet: ...
	def GetSubShape(self, theID: int) -> TopoDS_Face: ...
	def IsDone(self) -> bool: ...
	def LoadShape(self, theShape: TopoDS_Shape) -> bool: ...
	def OverlapElements(self) -> BRepExtrema_MapOfIntegerPackedMapOfInteger: ...
	def Perform(self) -> None: ...
	def SetTolerance(self, theTolerance: float) -> None: ...
	def Tolerance(self) -> float: ...

#classnotwrapped
class BRepExtrema_OverlapTool: ...

# harray1 classes
# harray2 classes
# hsequence classes

BRepExtrema_Poly_Distance = BRepExtrema_Poly.Distance



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *


class Hatch_SequenceOfLine:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> Hatch_Line: ...
    def Last(self) -> Hatch_Line: ...
    def Length(self) -> int: ...
    def Append(self, theItem: Hatch_Line) -> Hatch_Line: ...
    def Prepend(self, theItem: Hatch_Line) -> Hatch_Line: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> Hatch_Line: ...
    def SetValue(self, theIndex: int, theValue: Hatch_Line) -> None: ...

class Hatch_SequenceOfParameter:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> Hatch_Parameter: ...
    def Last(self) -> Hatch_Parameter: ...
    def Length(self) -> int: ...
    def Append(self, theItem: Hatch_Parameter) -> Hatch_Parameter: ...
    def Prepend(self, theItem: Hatch_Parameter) -> Hatch_Parameter: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> Hatch_Parameter: ...
    def SetValue(self, theIndex: int, theValue: Hatch_Parameter) -> None: ...

class Hatch_LineForm(IntEnum):
	Hatch_XLINE: int = ...
	Hatch_YLINE: int = ...
	Hatch_ANYLINE: int = ...
Hatch_XLINE = Hatch_LineForm.Hatch_XLINE
Hatch_YLINE = Hatch_LineForm.Hatch_YLINE
Hatch_ANYLINE = Hatch_LineForm.Hatch_ANYLINE

class Hatch_Hatcher:
	def __init__(self, Tol: float, Oriented: Optional[bool] = True) -> None: ...
	@overload
	def AddLine(self, L: gp_Lin2d, T: Optional[Hatch_LineForm] = Hatch_ANYLINE) -> None: ...
	@overload
	def AddLine(self, D: gp_Dir2d, Dist: float) -> None: ...
	def AddXLine(self, X: float) -> None: ...
	def AddYLine(self, Y: float) -> None: ...
	def Coordinate(self, I: int) -> float: ...
	def End(self, I: int, J: int) -> float: ...
	def EndIndex(self, I: int, J: int) -> Tuple[int, float]: ...
	def IsXLine(self, I: int) -> bool: ...
	def IsYLine(self, I: int) -> bool: ...
	def Line(self, I: int) -> gp_Lin2d: ...
	def LineForm(self, I: int) -> Hatch_LineForm: ...
	@overload
	def NbIntervals(self) -> int: ...
	@overload
	def NbIntervals(self, I: int) -> int: ...
	def NbLines(self) -> int: ...
	def Start(self, I: int, J: int) -> float: ...
	def StartIndex(self, I: int, J: int) -> Tuple[int, float]: ...
	@overload
	def Tolerance(self, Tol: float) -> None: ...
	@overload
	def Tolerance(self) -> float: ...
	@overload
	def Trim(self, L: gp_Lin2d, Index: Optional[int] = 0) -> None: ...
	@overload
	def Trim(self, L: gp_Lin2d, Start: float, End: float, Index: Optional[int] = 0) -> None: ...
	@overload
	def Trim(self, P1: gp_Pnt2d, P2: gp_Pnt2d, Index: Optional[int] = 0) -> None: ...

class Hatch_Line:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d, T: Hatch_LineForm) -> None: ...
	def AddIntersection(self, Par1: float, Start: bool, Index: int, Par2: float, theToler: float) -> None: ...

class Hatch_Parameter:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Par1: float, Start: bool, Index: Optional[int] = 0, Par2: Optional[float] = 0) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes




# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
XmlObjMgt module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_xmlobjmgt.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _XmlObjMgt
else:
    import _XmlObjMgt

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _XmlObjMgt.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _XmlObjMgt.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlObjMgt.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlObjMgt.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _XmlObjMgt.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _XmlObjMgt.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _XmlObjMgt.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _XmlObjMgt.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _XmlObjMgt.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _XmlObjMgt.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlObjMgt.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _XmlObjMgt.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _XmlObjMgt.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlObjMgt.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlObjMgt.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlObjMgt.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _XmlObjMgt.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _XmlObjMgt:
_XmlObjMgt.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _XmlObjMgt.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.LDOM
import OCC.Core.TCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.Storage

from enum import IntEnum
from OCC.Core.Exception import *



class xmlobjmgt(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def FindChildByName(*args) -> "XmlObjMgt_Element":
        r"""
        No available documentation.

        Parameters
        ----------
        theSource: XmlObjMgt_Element
        theName: XmlObjMgt_DOMString

        Returns
        -------
        XmlObjMgt_Element

        """
        return _XmlObjMgt.xmlobjmgt_FindChildByName(*args)

    @staticmethod
    def FindChildByRef(*args) -> "XmlObjMgt_Element":
        r"""
        No available documentation.

        Parameters
        ----------
        theSource: XmlObjMgt_Element
        theRefName: XmlObjMgt_DOMString

        Returns
        -------
        XmlObjMgt_Element

        """
        return _XmlObjMgt.xmlobjmgt_FindChildByRef(*args)

    @staticmethod
    def FindChildElement(*args) -> "XmlObjMgt_Element":
        r"""
        No available documentation.

        Parameters
        ----------
        theSource: XmlObjMgt_Element
        theObjId: int

        Returns
        -------
        XmlObjMgt_Element

        """
        return _XmlObjMgt.xmlobjmgt_FindChildElement(*args)

    @staticmethod
    def GetExtendedString(*args) -> "Standard_Boolean":
        r"""
        Get attribute <theelement extstring='thestring' ...>.

        Parameters
        ----------
        theElement: XmlObjMgt_Element
        theString: TCollection_ExtendedString

        Returns
        -------
        bool

        """
        return _XmlObjMgt.xmlobjmgt_GetExtendedString(*args)

    @staticmethod
    def GetInteger(*args) -> "Standard_Integer &":
        r"""
        No available documentation.

        Parameters
        ----------
        theString: char *

        Returns
        -------
        theValue: int

        """
        return _XmlObjMgt.xmlobjmgt_GetInteger(*args)

    @staticmethod
    def GetReal(*args) -> "Standard_Real &":
        r"""
        No available documentation.

        Parameters
        ----------
        theString: char *

        Returns
        -------
        theValue: float
        No available documentation.

        Parameters
        ----------
        theString: XmlObjMgt_DOMString

        Returns
        -------
        theValue: float

        """
        return _XmlObjMgt.xmlobjmgt_GetReal(*args)

    @staticmethod
    def GetStringValue(*args) -> "XmlObjMgt_DOMString":
        r"""
        Returns the first child text node.

        Parameters
        ----------
        theElement: XmlObjMgt_Element

        Returns
        -------
        XmlObjMgt_DOMString

        """
        return _XmlObjMgt.xmlobjmgt_GetStringValue(*args)

    @staticmethod
    def GetTagEntryString(*args) -> "Standard_Boolean":
        r"""
        Convert xpath expression (domstring) into tagentry string returns false on error.

        Parameters
        ----------
        theTarget: XmlObjMgt_DOMString
        theTagEntry: TCollection_AsciiString

        Returns
        -------
        bool

        """
        return _XmlObjMgt.xmlobjmgt_GetTagEntryString(*args)

    @staticmethod
    def IdString(*args) -> "XmlObjMgt_DOMString const &":
        r"""
        Define the name of xmlattribute 'id' (to be used everywhere).

        Returns
        -------
        XmlObjMgt_DOMString

        """
        return _XmlObjMgt.xmlobjmgt_IdString(*args)

    @staticmethod
    def SetExtendedString(*args) -> "Standard_Boolean":
        r"""
        Add attribute <theelement extstring='thestring' ...>.

        Parameters
        ----------
        theElement: XmlObjMgt_Element
        theString: TCollection_ExtendedString

        Returns
        -------
        bool

        """
        return _XmlObjMgt.xmlobjmgt_SetExtendedString(*args)

    @staticmethod
    def SetStringValue(*args) -> "void":
        r"""
        Add thedata as the last child text node to theelement iscleartext(true) avoids analysis of the string and replacement of characters like '<' and '&' during xml file storage. do never set iscleartext unless you have a hell of a reason.

        Parameters
        ----------
        theElement: XmlObjMgt_Element
        theData: XmlObjMgt_DOMString
        isClearText: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        return _XmlObjMgt.xmlobjmgt_SetStringValue(*args)

    @staticmethod
    def SetTagEntryString(*args) -> "void":
        r"""
        Convert xpath expression (domstring) into tagentry string returns false on error.

        Parameters
        ----------
        theSource: XmlObjMgt_DOMString
        theTagEntry: TCollection_AsciiString

        Returns
        -------
        None

        """
        return _XmlObjMgt.xmlobjmgt_SetTagEntryString(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _XmlObjMgt.xmlobjmgt_swiginit(self, _XmlObjMgt.new_xmlobjmgt())
    __swig_destroy__ = _XmlObjMgt.delete_xmlobjmgt

# Register xmlobjmgt in _XmlObjMgt:
_XmlObjMgt.xmlobjmgt_swigregister(xmlobjmgt)

def xmlobjmgt_FindChildByName(*args) -> "XmlObjMgt_Element":
    r"""
    No available documentation.

    Parameters
    ----------
    theSource: XmlObjMgt_Element
    theName: XmlObjMgt_DOMString

    Returns
    -------
    XmlObjMgt_Element

    """
    return _XmlObjMgt.xmlobjmgt_FindChildByName(*args)

def xmlobjmgt_FindChildByRef(*args) -> "XmlObjMgt_Element":
    r"""
    No available documentation.

    Parameters
    ----------
    theSource: XmlObjMgt_Element
    theRefName: XmlObjMgt_DOMString

    Returns
    -------
    XmlObjMgt_Element

    """
    return _XmlObjMgt.xmlobjmgt_FindChildByRef(*args)

def xmlobjmgt_FindChildElement(*args) -> "XmlObjMgt_Element":
    r"""
    No available documentation.

    Parameters
    ----------
    theSource: XmlObjMgt_Element
    theObjId: int

    Returns
    -------
    XmlObjMgt_Element

    """
    return _XmlObjMgt.xmlobjmgt_FindChildElement(*args)

def xmlobjmgt_GetExtendedString(*args) -> "Standard_Boolean":
    r"""
    Get attribute <theelement extstring='thestring' ...>.

    Parameters
    ----------
    theElement: XmlObjMgt_Element
    theString: TCollection_ExtendedString

    Returns
    -------
    bool

    """
    return _XmlObjMgt.xmlobjmgt_GetExtendedString(*args)

def xmlobjmgt_GetInteger(*args) -> "Standard_Integer &":
    r"""
    No available documentation.

    Parameters
    ----------
    theString: char *

    Returns
    -------
    theValue: int

    """
    return _XmlObjMgt.xmlobjmgt_GetInteger(*args)

def xmlobjmgt_GetReal(*args) -> "Standard_Real &":
    r"""
    No available documentation.

    Parameters
    ----------
    theString: char *

    Returns
    -------
    theValue: float
    No available documentation.

    Parameters
    ----------
    theString: XmlObjMgt_DOMString

    Returns
    -------
    theValue: float

    """
    return _XmlObjMgt.xmlobjmgt_GetReal(*args)

def xmlobjmgt_GetStringValue(*args) -> "XmlObjMgt_DOMString":
    r"""
    Returns the first child text node.

    Parameters
    ----------
    theElement: XmlObjMgt_Element

    Returns
    -------
    XmlObjMgt_DOMString

    """
    return _XmlObjMgt.xmlobjmgt_GetStringValue(*args)

def xmlobjmgt_GetTagEntryString(*args) -> "Standard_Boolean":
    r"""
    Convert xpath expression (domstring) into tagentry string returns false on error.

    Parameters
    ----------
    theTarget: XmlObjMgt_DOMString
    theTagEntry: TCollection_AsciiString

    Returns
    -------
    bool

    """
    return _XmlObjMgt.xmlobjmgt_GetTagEntryString(*args)

def xmlobjmgt_IdString(*args) -> "XmlObjMgt_DOMString const &":
    r"""
    Define the name of xmlattribute 'id' (to be used everywhere).

    Returns
    -------
    XmlObjMgt_DOMString

    """
    return _XmlObjMgt.xmlobjmgt_IdString(*args)

def xmlobjmgt_SetExtendedString(*args) -> "Standard_Boolean":
    r"""
    Add attribute <theelement extstring='thestring' ...>.

    Parameters
    ----------
    theElement: XmlObjMgt_Element
    theString: TCollection_ExtendedString

    Returns
    -------
    bool

    """
    return _XmlObjMgt.xmlobjmgt_SetExtendedString(*args)

def xmlobjmgt_SetStringValue(*args) -> "void":
    r"""
    Add thedata as the last child text node to theelement iscleartext(true) avoids analysis of the string and replacement of characters like '<' and '&' during xml file storage. do never set iscleartext unless you have a hell of a reason.

    Parameters
    ----------
    theElement: XmlObjMgt_Element
    theData: XmlObjMgt_DOMString
    isClearText: bool,optional
    	default value is Standard_False

    Returns
    -------
    None

    """
    return _XmlObjMgt.xmlobjmgt_SetStringValue(*args)

def xmlobjmgt_SetTagEntryString(*args) -> "void":
    r"""
    Convert xpath expression (domstring) into tagentry string returns false on error.

    Parameters
    ----------
    theSource: XmlObjMgt_DOMString
    theTagEntry: TCollection_AsciiString

    Returns
    -------
    None

    """
    return _XmlObjMgt.xmlobjmgt_SetTagEntryString(*args)

class XmlObjMgt_Array1(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Create an array of lower bound <low> and upper bound <up>. range error is raised when <up> is less than <low>.

        Parameters
        ----------
        Low: int
        Up: int

        Returns
        -------
        None
        For restoration from dom_element which is child of theparent: <theparent ...> <thename ...>.

        Parameters
        ----------
        theParent: XmlObjMgt_Element
        theName: XmlObjMgt_DOMString

        Returns
        -------
        None

        """
        _XmlObjMgt.XmlObjMgt_Array1_swiginit(self, _XmlObjMgt.new_XmlObjMgt_Array1(*args))

    def CreateArrayElement(self, *args) -> "void":
        r"""
        Create dom_element representing the array, under 'theparent'.

        Parameters
        ----------
        theParent: XmlObjMgt_Element
        theName: XmlObjMgt_DOMString

        Returns
        -------
        None

        """
        return _XmlObjMgt.XmlObjMgt_Array1_CreateArrayElement(self, *args)

    def Element(self, *args) -> "XmlObjMgt_Element const &":
        r"""
        Returns the dom element of <self>.

        Returns
        -------
        XmlObjMgt_Element

        """
        return _XmlObjMgt.XmlObjMgt_Array1_Element(self, *args)

    def Length(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of elements of <self>.

        Returns
        -------
        int

        """
        return _XmlObjMgt.XmlObjMgt_Array1_Length(self, *args)

    def Lower(self, *args) -> "Standard_Integer":
        r"""
        Returns the lower bound.

        Returns
        -------
        int

        """
        return _XmlObjMgt.XmlObjMgt_Array1_Lower(self, *args)

    def SetValue(self, *args) -> "void":
        r"""
        Set the <index>th element of the array to <value>.

        Parameters
        ----------
        Index: int
        Value: XmlObjMgt_Element

        Returns
        -------
        None

        """
        return _XmlObjMgt.XmlObjMgt_Array1_SetValue(self, *args)

    def Upper(self, *args) -> "Standard_Integer":
        r"""
        Returns the upper bound.

        Returns
        -------
        int

        """
        return _XmlObjMgt.XmlObjMgt_Array1_Upper(self, *args)

    def Value(self, *args) -> "XmlObjMgt_Element":
        r"""
        Returns the value of <index>th element of the array.

        Parameters
        ----------
        Index: int

        Returns
        -------
        XmlObjMgt_Element

        """
        return _XmlObjMgt.XmlObjMgt_Array1_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _XmlObjMgt.delete_XmlObjMgt_Array1

# Register XmlObjMgt_Array1 in _XmlObjMgt:
_XmlObjMgt.XmlObjMgt_Array1_swigregister(XmlObjMgt_Array1)

class XmlObjMgt_GP(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Translate(*args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        aTrsf: gp_Trsf

        Returns
        -------
        XmlObjMgt_DOMString
        No available documentation.

        Parameters
        ----------
        aMat: gp_Mat

        Returns
        -------
        XmlObjMgt_DOMString
        No available documentation.

        Parameters
        ----------
        anXYZ: gp_XYZ

        Returns
        -------
        XmlObjMgt_DOMString
        No available documentation.

        Parameters
        ----------
        aStr: XmlObjMgt_DOMString
        T: gp_Trsf

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        aStr: XmlObjMgt_DOMString
        T: gp_Mat

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        aStr: XmlObjMgt_DOMString
        T: gp_XYZ

        Returns
        -------
        bool

        """
        return _XmlObjMgt.XmlObjMgt_GP_Translate(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _XmlObjMgt.XmlObjMgt_GP_swiginit(self, _XmlObjMgt.new_XmlObjMgt_GP())
    __swig_destroy__ = _XmlObjMgt.delete_XmlObjMgt_GP

# Register XmlObjMgt_GP in _XmlObjMgt:
_XmlObjMgt.XmlObjMgt_GP_swigregister(XmlObjMgt_GP)

def XmlObjMgt_GP_Translate(*args) -> "Standard_Boolean":
    r"""
    No available documentation.

    Parameters
    ----------
    aTrsf: gp_Trsf

    Returns
    -------
    XmlObjMgt_DOMString
    No available documentation.

    Parameters
    ----------
    aMat: gp_Mat

    Returns
    -------
    XmlObjMgt_DOMString
    No available documentation.

    Parameters
    ----------
    anXYZ: gp_XYZ

    Returns
    -------
    XmlObjMgt_DOMString
    No available documentation.

    Parameters
    ----------
    aStr: XmlObjMgt_DOMString
    T: gp_Trsf

    Returns
    -------
    bool
    No available documentation.

    Parameters
    ----------
    aStr: XmlObjMgt_DOMString
    T: gp_Mat

    Returns
    -------
    bool
    No available documentation.

    Parameters
    ----------
    aStr: XmlObjMgt_DOMString
    T: gp_XYZ

    Returns
    -------
    bool

    """
    return _XmlObjMgt.XmlObjMgt_GP_Translate(*args)

class XmlObjMgt_Persistent(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None
        Constructor.

        Parameters
        ----------
        theElement: XmlObjMgt_Element

        Returns
        -------
        None
        Constructor from sub-element of element referenced by theref.

        Parameters
        ----------
        theElement: XmlObjMgt_Element
        theRef: XmlObjMgt_DOMString

        Returns
        -------
        None

        """
        _XmlObjMgt.XmlObjMgt_Persistent_swiginit(self, _XmlObjMgt.new_XmlObjMgt_Persistent(*args))

    def CreateElement(self, *args) -> "void":
        r"""
        Myelement := <thetype id='theid'/>.

        Parameters
        ----------
        theParent: XmlObjMgt_Element
        theType: XmlObjMgt_DOMString
        theID: int

        Returns
        -------
        None

        """
        return _XmlObjMgt.XmlObjMgt_Persistent_CreateElement(self, *args)

    def Element(self, *args) -> "XmlObjMgt_Element const &":
        r"""
        Return myelement.

        Returns
        -------
        XmlObjMgt_Element

        """
        return _XmlObjMgt.XmlObjMgt_Persistent_Element(self, *args)

    def Id(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _XmlObjMgt.XmlObjMgt_Persistent_Id(self, *args)

    def SetId(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theId: int

        Returns
        -------
        None

        """
        return _XmlObjMgt.XmlObjMgt_Persistent_SetId(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _XmlObjMgt.delete_XmlObjMgt_Persistent

# Register XmlObjMgt_Persistent in _XmlObjMgt:
_XmlObjMgt.XmlObjMgt_Persistent_swigregister(XmlObjMgt_Persistent)

class XmlObjMgt_RRelocationTable(OCC.Core.TColStd.TColStd_DataMapOfIntegerTransient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def Clear(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        doReleaseMemory: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _XmlObjMgt.XmlObjMgt_RRelocationTable_Clear(self, *args)

    def GetHeaderData(self, *args) -> "opencascade::handle< Storage_HeaderData > const &":
        r"""
        Returns a handle to the header data of the file that is begin read.

        Returns
        -------
        opencascade::handle<Storage_HeaderData>

        """
        return _XmlObjMgt.XmlObjMgt_RRelocationTable_GetHeaderData(self, *args)

    def SetHeaderData(self, *args) -> "void":
        r"""
        Sets the storage header data. //! @param theheaderdata header data of the file that is begin read.

        Parameters
        ----------
        theHeaderData: Storage_HeaderData

        Returns
        -------
        None

        """
        return _XmlObjMgt.XmlObjMgt_RRelocationTable_SetHeaderData(self, *args)

    __repr__ = _dumps_object


    def __init__(self):
        _XmlObjMgt.XmlObjMgt_RRelocationTable_swiginit(self, _XmlObjMgt.new_XmlObjMgt_RRelocationTable())
    __swig_destroy__ = _XmlObjMgt.delete_XmlObjMgt_RRelocationTable

# Register XmlObjMgt_RRelocationTable in _XmlObjMgt:
_XmlObjMgt.XmlObjMgt_RRelocationTable_swigregister(XmlObjMgt_RRelocationTable)

class XmlObjMgt_SRelocationTable(OCC.Core.TColStd.TColStd_IndexedMapOfTransient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def Clear(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        doReleaseMemory: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _XmlObjMgt.XmlObjMgt_SRelocationTable_Clear(self, *args)

    def GetHeaderData(self, *args) -> "opencascade::handle< Storage_HeaderData > const &":
        r"""
        Returns a handle to the header data of the file that is begin read.

        Returns
        -------
        opencascade::handle<Storage_HeaderData>

        """
        return _XmlObjMgt.XmlObjMgt_SRelocationTable_GetHeaderData(self, *args)

    def SetHeaderData(self, *args) -> "void":
        r"""
        Sets the storage header data. //! @param theheaderdata header data of the file that is begin read.

        Parameters
        ----------
        theHeaderData: Storage_HeaderData

        Returns
        -------
        None

        """
        return _XmlObjMgt.XmlObjMgt_SRelocationTable_SetHeaderData(self, *args)

    __repr__ = _dumps_object


    def __init__(self):
        _XmlObjMgt.XmlObjMgt_SRelocationTable_swiginit(self, _XmlObjMgt.new_XmlObjMgt_SRelocationTable())
    __swig_destroy__ = _XmlObjMgt.delete_XmlObjMgt_SRelocationTable

# Register XmlObjMgt_SRelocationTable in _XmlObjMgt:
_XmlObjMgt.XmlObjMgt_SRelocationTable_swigregister(XmlObjMgt_SRelocationTable)


XmlObjMgt_Document=OCC.Core.LDOM.LDOM_Document
XmlObjMgt_Element=OCC.Core.LDOM.LDOM_Element






from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.BRep import *
from OCC.Core.TopoDS import *
from OCC.Core.TopAbs import *
from OCC.Core.Sweep import *
from OCC.Core.gp import *
from OCC.Core.TopLoc import *


class BRepSweep_Builder:
	def __init__(self, aBuilder: BRep_Builder) -> None: ...
	@overload
	def Add(self, aShape1: TopoDS_Shape, aShape2: TopoDS_Shape, Orient: TopAbs_Orientation) -> None: ...
	@overload
	def Add(self, aShape1: TopoDS_Shape, aShape2: TopoDS_Shape) -> None: ...
	def Builder(self) -> BRep_Builder: ...
	def MakeCompSolid(self, aCompSolid: TopoDS_Shape) -> None: ...
	def MakeCompound(self, aCompound: TopoDS_Shape) -> None: ...
	def MakeShell(self, aShell: TopoDS_Shape) -> None: ...
	def MakeSolid(self, aSolid: TopoDS_Shape) -> None: ...
	def MakeWire(self, aWire: TopoDS_Shape) -> None: ...

class BRepSweep_Iterator:
	def __init__(self) -> None: ...
	def Init(self, aShape: TopoDS_Shape) -> None: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Orientation(self) -> TopAbs_Orientation: ...
	def Value(self) -> TopoDS_Shape: ...

class BRepSweep_NumLinearRegularSweep:
	def Closed(self) -> bool: ...
	def DirectSolid(self, aGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> TopAbs_Orientation: ...
	@overload
	def FirstShape(self) -> TopoDS_Shape: ...
	@overload
	def FirstShape(self, aGenS: TopoDS_Shape) -> TopoDS_Shape: ...
	def GDDShapeIsToAdd(self, aNewShape: TopoDS_Shape, aNewSubShape: TopoDS_Shape, aGenS: TopoDS_Shape, aDirS: Sweep_NumShape, aSubDirS: Sweep_NumShape) -> bool: ...
	def GGDShapeIsToAdd(self, aNewShape: TopoDS_Shape, aNewSubShape: TopoDS_Shape, aGenS: TopoDS_Shape, aSubGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> bool: ...
	def GenIsUsed(self, theS: TopoDS_Shape) -> bool: ...
	def HasShape(self, aGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> bool: ...
	def IsInvariant(self, aGenS: TopoDS_Shape) -> bool: ...
	def IsUsed(self, aGenS: TopoDS_Shape) -> bool: ...
	@overload
	def LastShape(self) -> TopoDS_Shape: ...
	@overload
	def LastShape(self, aGenS: TopoDS_Shape) -> TopoDS_Shape: ...
	def MakeEmptyDirectingEdge(self, aGenV: TopoDS_Shape, aDirE: Sweep_NumShape) -> TopoDS_Shape: ...
	def MakeEmptyFace(self, aGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> TopoDS_Shape: ...
	def MakeEmptyGeneratingEdge(self, aGenE: TopoDS_Shape, aDirV: Sweep_NumShape) -> TopoDS_Shape: ...
	def MakeEmptyVertex(self, aGenV: TopoDS_Shape, aDirV: Sweep_NumShape) -> TopoDS_Shape: ...
	def SeparatedWires(self, aNewShape: TopoDS_Shape, aNewSubShape: TopoDS_Shape, aGenS: TopoDS_Shape, aSubGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> bool: ...
	def SetContinuity(self, aGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> None: ...
	def SetDirectingPCurve(self, aNewFace: TopoDS_Shape, aNewEdge: TopoDS_Shape, aGenE: TopoDS_Shape, aGenV: TopoDS_Shape, aDirE: Sweep_NumShape, orien: TopAbs_Orientation) -> None: ...
	def SetDirectingParameter(self, aNewEdge: TopoDS_Shape, aNewVertex: TopoDS_Shape, aGenV: TopoDS_Shape, aDirE: Sweep_NumShape, aDirV: Sweep_NumShape) -> None: ...
	def SetGeneratingPCurve(self, aNewFace: TopoDS_Shape, aNewEdge: TopoDS_Shape, aGenE: TopoDS_Shape, aDirE: Sweep_NumShape, aDirV: Sweep_NumShape, orien: TopAbs_Orientation) -> None: ...
	def SetGeneratingParameter(self, aNewEdge: TopoDS_Shape, aNewVertex: TopoDS_Shape, aGenE: TopoDS_Shape, aGenV: TopoDS_Shape, aDirV: Sweep_NumShape) -> None: ...
	def SetPCurve(self, aNewFace: TopoDS_Shape, aNewEdge: TopoDS_Shape, aGenF: TopoDS_Shape, aGenE: TopoDS_Shape, aDirV: Sweep_NumShape, orien: TopAbs_Orientation) -> None: ...
	def SetParameters(self, aNewFace: TopoDS_Shape, aNewVertex: TopoDS_Shape, aGenF: TopoDS_Shape, aGenV: TopoDS_Shape, aDirV: Sweep_NumShape) -> None: ...
	@overload
	def Shape(self, aGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> TopoDS_Shape: ...
	@overload
	def Shape(self, aGenS: TopoDS_Shape) -> TopoDS_Shape: ...
	@overload
	def Shape(self) -> TopoDS_Shape: ...
	def SplitShell(self, aNewShape: TopoDS_Shape) -> TopoDS_Shape: ...

class BRepSweep_Prism:
	@overload
	def __init__(self, S: TopoDS_Shape, V: gp_Vec, Copy: Optional[bool] = False, Canonize: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape, D: gp_Dir, Inf: Optional[bool] = True, Copy: Optional[bool] = False, Canonize: Optional[bool] = True) -> None: ...
	@overload
	def FirstShape(self) -> TopoDS_Shape: ...
	@overload
	def FirstShape(self, aGenS: TopoDS_Shape) -> TopoDS_Shape: ...
	def GenIsUsed(self, theS: TopoDS_Shape) -> bool: ...
	def IsUsed(self, aGenS: TopoDS_Shape) -> bool: ...
	@overload
	def LastShape(self) -> TopoDS_Shape: ...
	@overload
	def LastShape(self, aGenS: TopoDS_Shape) -> TopoDS_Shape: ...
	@overload
	def Shape(self) -> TopoDS_Shape: ...
	@overload
	def Shape(self, aGenS: TopoDS_Shape) -> TopoDS_Shape: ...
	def Vec(self) -> gp_Vec: ...

class BRepSweep_Revol:
	@overload
	def __init__(self, S: TopoDS_Shape, A: gp_Ax1, D: float, C: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape, A: gp_Ax1, C: Optional[bool] = False) -> None: ...
	def Angle(self) -> float: ...
	def Axe(self) -> gp_Ax1: ...
	@overload
	def FirstShape(self) -> TopoDS_Shape: ...
	@overload
	def FirstShape(self, aGenS: TopoDS_Shape) -> TopoDS_Shape: ...
	def IsUsed(self, aGenS: TopoDS_Shape) -> bool: ...
	@overload
	def LastShape(self) -> TopoDS_Shape: ...
	@overload
	def LastShape(self, aGenS: TopoDS_Shape) -> TopoDS_Shape: ...
	@overload
	def Shape(self) -> TopoDS_Shape: ...
	@overload
	def Shape(self, aGenS: TopoDS_Shape) -> TopoDS_Shape: ...

class BRepSweep_Tool:
	def __init__(self, aShape: TopoDS_Shape) -> None: ...
	def Index(self, aShape: TopoDS_Shape) -> int: ...
	def NbShapes(self) -> int: ...
	def Orientation(self, aShape: TopoDS_Shape) -> TopAbs_Orientation: ...
	def SetOrientation(self, aShape: TopoDS_Shape, Or: TopAbs_Orientation) -> None: ...
	def Shape(self, anIndex: int) -> TopoDS_Shape: ...
	def Type(self, aShape: TopoDS_Shape) -> TopAbs_ShapeEnum: ...

class BRepSweep_Trsf(BRepSweep_NumLinearRegularSweep):
	def GDDShapeIsToAdd(self, aNewShape: TopoDS_Shape, aNewSubShape: TopoDS_Shape, aGenS: TopoDS_Shape, aDirS: Sweep_NumShape, aSubDirS: Sweep_NumShape) -> bool: ...
	def GGDShapeIsToAdd(self, aNewShape: TopoDS_Shape, aNewSubShape: TopoDS_Shape, aGenS: TopoDS_Shape, aSubGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> bool: ...
	def HasShape(self, aGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> bool: ...
	def Init(self) -> None: ...
	def IsInvariant(self, aGenS: TopoDS_Shape) -> bool: ...
	def MakeEmptyDirectingEdge(self, aGenV: TopoDS_Shape, aDirE: Sweep_NumShape) -> TopoDS_Shape: ...
	def MakeEmptyFace(self, aGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> TopoDS_Shape: ...
	def MakeEmptyGeneratingEdge(self, aGenE: TopoDS_Shape, aDirV: Sweep_NumShape) -> TopoDS_Shape: ...
	def MakeEmptyVertex(self, aGenV: TopoDS_Shape, aDirV: Sweep_NumShape) -> TopoDS_Shape: ...
	def Process(self, aGenS: TopoDS_Shape, aDirV: Sweep_NumShape) -> bool: ...
	def SeparatedWires(self, aNewShape: TopoDS_Shape, aNewSubShape: TopoDS_Shape, aGenS: TopoDS_Shape, aSubGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> bool: ...
	def SetContinuity(self, aGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> None: ...
	def SetDirectingPCurve(self, aNewFace: TopoDS_Shape, aNewEdge: TopoDS_Shape, aGenE: TopoDS_Shape, aGenV: TopoDS_Shape, aDirE: Sweep_NumShape, orien: TopAbs_Orientation) -> None: ...
	def SetDirectingParameter(self, aNewEdge: TopoDS_Shape, aNewVertex: TopoDS_Shape, aGenV: TopoDS_Shape, aDirE: Sweep_NumShape, aDirV: Sweep_NumShape) -> None: ...
	def SetGeneratingPCurve(self, aNewFace: TopoDS_Shape, aNewEdge: TopoDS_Shape, aGenE: TopoDS_Shape, aDirE: Sweep_NumShape, aDirV: Sweep_NumShape, orien: TopAbs_Orientation) -> None: ...
	def SetGeneratingParameter(self, aNewEdge: TopoDS_Shape, aNewVertex: TopoDS_Shape, aGenE: TopoDS_Shape, aGenV: TopoDS_Shape, aDirV: Sweep_NumShape) -> None: ...
	def SetPCurve(self, aNewFace: TopoDS_Shape, aNewEdge: TopoDS_Shape, aGenF: TopoDS_Shape, aGenE: TopoDS_Shape, aDirV: Sweep_NumShape, orien: TopAbs_Orientation) -> None: ...
	def SetParameters(self, aNewFace: TopoDS_Shape, aNewVertex: TopoDS_Shape, aGenF: TopoDS_Shape, aGenV: TopoDS_Shape, aDirV: Sweep_NumShape) -> None: ...

class BRepSweep_Rotation(BRepSweep_Trsf):
	def __init__(self, S: TopoDS_Shape, N: Sweep_NumShape, L: TopLoc_Location, A: gp_Ax1, D: float, C: bool) -> None: ...
	def Angle(self) -> float: ...
	def Axe(self) -> gp_Ax1: ...
	def DirectSolid(self, aGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> TopAbs_Orientation: ...
	def GDDShapeIsToAdd(self, aNewShape: TopoDS_Shape, aNewSubShape: TopoDS_Shape, aGenS: TopoDS_Shape, aDirS: Sweep_NumShape, aSubDirS: Sweep_NumShape) -> bool: ...
	def GGDShapeIsToAdd(self, aNewShape: TopoDS_Shape, aNewSubShape: TopoDS_Shape, aGenS: TopoDS_Shape, aSubGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> bool: ...
	def HasShape(self, aGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> bool: ...
	def IsInvariant(self, aGenS: TopoDS_Shape) -> bool: ...
	def MakeEmptyDirectingEdge(self, aGenV: TopoDS_Shape, aDirE: Sweep_NumShape) -> TopoDS_Shape: ...
	def MakeEmptyFace(self, aGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> TopoDS_Shape: ...
	def MakeEmptyGeneratingEdge(self, aGenE: TopoDS_Shape, aDirV: Sweep_NumShape) -> TopoDS_Shape: ...
	def MakeEmptyVertex(self, aGenV: TopoDS_Shape, aDirV: Sweep_NumShape) -> TopoDS_Shape: ...
	def SeparatedWires(self, aNewShape: TopoDS_Shape, aNewSubShape: TopoDS_Shape, aGenS: TopoDS_Shape, aSubGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> bool: ...
	def SetDirectingPCurve(self, aNewFace: TopoDS_Shape, aNewEdge: TopoDS_Shape, aGenE: TopoDS_Shape, aGenV: TopoDS_Shape, aDirE: Sweep_NumShape, orien: TopAbs_Orientation) -> None: ...
	def SetDirectingParameter(self, aNewEdge: TopoDS_Shape, aNewVertex: TopoDS_Shape, aGenV: TopoDS_Shape, aDirE: Sweep_NumShape, aDirV: Sweep_NumShape) -> None: ...
	def SetGeneratingPCurve(self, aNewFace: TopoDS_Shape, aNewEdge: TopoDS_Shape, aGenE: TopoDS_Shape, aDirE: Sweep_NumShape, aDirV: Sweep_NumShape, orien: TopAbs_Orientation) -> None: ...
	def SetGeneratingParameter(self, aNewEdge: TopoDS_Shape, aNewVertex: TopoDS_Shape, aGenE: TopoDS_Shape, aGenV: TopoDS_Shape, aDirV: Sweep_NumShape) -> None: ...
	def SetPCurve(self, aNewFace: TopoDS_Shape, aNewEdge: TopoDS_Shape, aGenF: TopoDS_Shape, aGenE: TopoDS_Shape, aDirV: Sweep_NumShape, orien: TopAbs_Orientation) -> None: ...
	def SetParameters(self, aNewFace: TopoDS_Shape, aNewVertex: TopoDS_Shape, aGenF: TopoDS_Shape, aGenV: TopoDS_Shape, aDirV: Sweep_NumShape) -> None: ...
	def SplitShell(self, aNewShape: TopoDS_Shape) -> TopoDS_Shape: ...

class BRepSweep_Translation(BRepSweep_Trsf):
	def __init__(self, S: TopoDS_Shape, N: Sweep_NumShape, L: TopLoc_Location, V: gp_Vec, C: bool, Canonize: Optional[bool] = True) -> None: ...
	def DirectSolid(self, aGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> TopAbs_Orientation: ...
	def GDDShapeIsToAdd(self, aNewShape: TopoDS_Shape, aNewSubShape: TopoDS_Shape, aGenS: TopoDS_Shape, aDirS: Sweep_NumShape, aSubDirS: Sweep_NumShape) -> bool: ...
	def GGDShapeIsToAdd(self, aNewShape: TopoDS_Shape, aNewSubShape: TopoDS_Shape, aGenS: TopoDS_Shape, aSubGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> bool: ...
	def HasShape(self, aGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> bool: ...
	def IsInvariant(self, aGenS: TopoDS_Shape) -> bool: ...
	def MakeEmptyDirectingEdge(self, aGenV: TopoDS_Shape, aDirE: Sweep_NumShape) -> TopoDS_Shape: ...
	def MakeEmptyFace(self, aGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> TopoDS_Shape: ...
	def MakeEmptyGeneratingEdge(self, aGenE: TopoDS_Shape, aDirV: Sweep_NumShape) -> TopoDS_Shape: ...
	def MakeEmptyVertex(self, aGenV: TopoDS_Shape, aDirV: Sweep_NumShape) -> TopoDS_Shape: ...
	def SeparatedWires(self, aNewShape: TopoDS_Shape, aNewSubShape: TopoDS_Shape, aGenS: TopoDS_Shape, aSubGenS: TopoDS_Shape, aDirS: Sweep_NumShape) -> bool: ...
	def SetDirectingPCurve(self, aNewFace: TopoDS_Shape, aNewEdge: TopoDS_Shape, aGenE: TopoDS_Shape, aGenV: TopoDS_Shape, aDirE: Sweep_NumShape, orien: TopAbs_Orientation) -> None: ...
	def SetDirectingParameter(self, aNewEdge: TopoDS_Shape, aNewVertex: TopoDS_Shape, aGenV: TopoDS_Shape, aDirE: Sweep_NumShape, aDirV: Sweep_NumShape) -> None: ...
	def SetGeneratingPCurve(self, aNewFace: TopoDS_Shape, aNewEdge: TopoDS_Shape, aGenE: TopoDS_Shape, aDirE: Sweep_NumShape, aDirV: Sweep_NumShape, orien: TopAbs_Orientation) -> None: ...
	def SetGeneratingParameter(self, aNewEdge: TopoDS_Shape, aNewVertex: TopoDS_Shape, aGenE: TopoDS_Shape, aGenV: TopoDS_Shape, aDirV: Sweep_NumShape) -> None: ...
	def SetPCurve(self, aNewFace: TopoDS_Shape, aNewEdge: TopoDS_Shape, aGenF: TopoDS_Shape, aGenE: TopoDS_Shape, aDirV: Sweep_NumShape, orien: TopAbs_Orientation) -> None: ...
	def SetParameters(self, aNewFace: TopoDS_Shape, aNewVertex: TopoDS_Shape, aGenF: TopoDS_Shape, aGenV: TopoDS_Shape, aDirV: Sweep_NumShape) -> None: ...
	def Vec(self) -> gp_Vec: ...

# harray1 classes
# harray2 classes
# hsequence classes

